@@ -3,6 +3,7 @@
 #Could make bounce effect when hit boundaries by sending in opposite direction for count down moment
 #could make accelrate faster by using previuos x,y as well as start x,y as startx,y means you cant accelerate until back to starting point.
 
+#15.05.10    copy snapy.dat.reset with write permissions if not already found. Avoids file overwrite if installing new version
 #13.05.10    Fixed all paths to point to opt/snapy instead of opt root
 #               Increase speed per level
 #               Reset acceleration at start each level
@@ -21,7 +22,7 @@
 #23.03.10:  Made snapy controled by accelerometer
 
 
-import sys, pygame, time,  math,  os,  dbus,  random,  osso
+import sys, pygame, time,  math,  os,  dbus,  random,  osso, shutil
 
 from pygame.locals import *
 import pygame.mixer
@@ -371,7 +372,15 @@ def load_game_settings():
     try:
         file = open("/home/opt/snapy/snapy.dat" , 'r')  #open("/home/opt/snapy.dat" , 'r')
     except:
-        save_game_settings()
+        try:
+            #Make copy with write attribute set
+            print "Copy reset file..."
+            shutil.copy2('/home/opt/snapy/snapy.dat.reset', 'snapy.dat')
+            save_game_settings()
+        except:
+            print "Error resetting score..."
+            return
+        print "Error opening score file..."
         return
     try:
         buffer = file.readline()
